==> react-grid-layout-0.13.7-0.jar: cljsjs/react-grid-layout/common/react-grid-layout.ext.js <==
// Generated via http://jmmk.github.io/javascript-externs-generator/
// Import react via cdn
// Import react-grid-layout via rawgit

// Loaded JavaScripts:
// https://unpkg.com/react@15.3.2/dist/react.js
// https://rawgit.com/STRML/react-grid-layout/0.13.7/dist/react-grid-layout.min.js

// Reference ns as ReactGridLayout

var ReactGridLayout = {
  "displayName": {},
  "propTypes": {
    "className": {
      "isRequired": function () {}
    },
    "style": {
      "isRequired": function () {}
    },
    "width": {
      "isRequired": function () {}
    },
    "autoSize": {
      "isRequired": function () {}
    },
    "cols": {
      "isRequired": function () {}
    },
    "draggableCancel": {
      "isRequired": function () {}
    },
    "draggableHandle": {
      "isRequired": function () {}
    },
    "verticalCompact": {
      "isRequired": function () {}
    },
    "layout": function () {},
    "margin": {
      "isRequired": function () {}
    },
    "containerPadding": {
      "isRequired": function () {}
    },
    "rowHeight": {
      "isRequired": function () {}
    },
    "maxRows": {
      "isRequired": function () {}
    },
    "isDraggable": {
      "isRequired": function () {}
    },
    "isResizable": {
      "isRequired": function () {}
    },
    "useCSSTransforms": {
      "isRequired": function () {}
    },
    "onLayoutChange": {
      "isRequired": function () {}
    },
    "onDragStart": {
      "isRequired": function () {}
    },
    "onDrag": {
      "isRequired": function () {}
    },
    "onDragStop": {
      "isRequired": function () {}
    },
    "onResizeStart": {
      "isRequired": function () {}
    },
    "onResize": {
      "isRequired": function () {}
    },
    "onResizeStop": {
      "isRequired": function () {}
    },
    "children": function () {}
  },
  "defaultProps": {
    "autoSize": {},
    "cols": {},
    "className": {},
    "rowHeight": {},
    "maxRows": {},
    "layout": {},
    "margin": {},
    "isDraggable": {},
    "isResizable": {},
    "useCSSTransforms": {},
    "verticalCompact": {},
    "onLayoutChange": function () {},
    "onDragStart": function () {},
    "onDrag": function () {},
    "onDragStop": function () {},
    "onResizeStart": function () {},
    "onResize": function () {},
    "onResizeStop": function () {}
  },
  "utils": {
    "__esModule": {},
    "bottom": function () {},
    "cloneLayout": function () {},
    "cloneLayoutItem": function () {},
    "childrenEqual": function () {},
    "collides": function () {},
    "compact": function () {},
    "compactItem": function () {},
    "correctBounds": function () {},
    "getLayoutItem": function () {},
    "getFirstCollision": function () {},
    "getAllCollisions": function () {},
    "getStatics": function () {},
    "moveElement": function () {},
    "moveElementAwayFromCollision": function () {},
    "perc": function () {},
    "setTransform": function () {},
    "setTopLeft": function () {},
    "sortLayoutItemsByRowCol": function () {},
    "synchronizeLayoutWithChildren": function () {},
    "validateLayout": function () {},
    "autoBindHandlers": function () {}
  },
  "Responsive": {
    "propTypes": {
      "breakpoint": {
        "isRequired": function () {}
      },
      "breakpoints": {
        "isRequired": function () {}
      },
      "cols": {
        "isRequired": function () {}
      },
      "layouts": function () {},
      "width": function () {},
      "onBreakpointChange": {
        "isRequired": function () {}
      },
      "onLayoutChange": {
        "isRequired": function () {}
      },
      "onWidthChange": {
        "isRequired": function () {}
      }
    },
    "defaultProps": {
      "breakpoints": {
        "lg": {},
        "md": {},
        "sm": {},
        "xs": {},
        "xxs": {}
      },
      "cols": {
        "lg": {},
        "md": {},
        "sm": {},
        "xs": {},
        "xxs": {}
      },
      "layouts": {},
      "onBreakpointChange": function () {},
      "onLayoutChange": function () {},
      "onWidthChange": function () {}
    },
    "utils": {
      "__esModule": {},
      "getBreakpointFromWidth": function () {},
      "getColsFromBreakpoint": function () {},
      "findOrGenerateResponsiveLayout": function () {},
      "sortBreakpoints": function () {}
    }
  },
  "WidthProvider": function () {}
};
ReactGridLayout.prototype = {
  "componentDidMount": function () {},
  "componentWillReceiveProps": function () {},
  "containerHeight": function () {},
  "onDragStart": function () {},
  "onDrag": function () {},
  "onDragStop": function () {},
  "onLayoutMaybeChanged": function () {},
  "onResizeStart": function () {},
  "onResize": function () {},
  "onResizeStop": function () {},
  "placeholder": function () {},
  "processGridItem": function () {},
  "render": function () {},
  "isReactComponent": function () {},
  "setState": function () {},
  "forceUpdate": function () {}
};
ReactGridLayout.Responsive.prototype = {
  "generateInitialState": function () {},
  "componentWillReceiveProps": function () {},
  "onWidthChange": function () {},
  "render": function () {},
  "isReactComponent": function () {},
  "setState": function () {},
  "forceUpdate": function () {}
};

==> react-grid-layout-0.13.9-0.jar: cljsjs/react-grid-layout/common/react-grid-layout.ext.js <==
// Generated via http://jmmk.github.io/javascript-externs-generator/
// Import react via cdn
// Import react-grid-layout via rawgit

// Loaded JavaScripts:
// https://unpkg.com/react@15.3.2/dist/react.js
// https://rawgit.com/STRML/react-grid-layout/0.13.9/dist/react-grid-layout.min.js

// Reference ns as ReactGridLayout
var ReactGridLayout = {
  "Responsive": {
    "defaultProps": {
      "breakpoints": {
        "lg": {},
        "md": {},
        "sm": {},
        "xs": {},
        "xxs": {}
      },
      "cols": {
        "lg": {},
        "md": {},
        "sm": {},
        "xs": {},
        "xxs": {}
      },
      "layouts": {},
      "onBreakpointChange": function () {},
      "onLayoutChange": function () {},
      "onWidthChange": function () {}
    },
    "propTypes": {
      "breakpoint": {
        "isRequired": function () {}
      },
      "breakpoints": {
        "isRequired": function () {}
      },
      "cols": {
        "isRequired": function () {}
      },
      "layouts": function () {},
      "onBreakpointChange": {
        "isRequired": function () {}
      },
      "onLayoutChange": {
        "isRequired": function () {}
      },
      "onWidthChange": {
        "isRequired": function () {}
      },
      "width": function () {}
    },
    "utils": {
      "__esModule": {},
      "findOrGenerateResponsiveLayout": function () {},
      "getBreakpointFromWidth": function () {},
      "getColsFromBreakpoint": function () {},
      "sortBreakpoints": function () {}
    }
  },
  "WidthProvider": function () {},
  "defaultProps": {
    "autoSize": {},
    "className": {},
    "cols": {},
    "isDraggable": {},
    "isResizable": {},
    "layout": {},
    "margin": {},
    "maxRows": {},
    "onDrag": function () {},
    "onDragStart": function () {},
    "onDragStop": function () {},
    "onLayoutChange": function () {},
    "onResize": function () {},
    "onResizeStart": function () {},
    "onResizeStop": function () {},
    "rowHeight": {},
    "useCSSTransforms": {},
    "verticalCompact": {}
  },
  "displayName": {},
  "propTypes": {
    "autoSize": {
      "isRequired": function () {}
    },
    "children": function () {},
    "className": {
      "isRequired": function () {}
    },
    "cols": {
      "isRequired": function () {}
    },
    "containerPadding": {
      "isRequired": function () {}
    },
    "draggableCancel": {
      "isRequired": function () {}
    },
    "draggableHandle": {
      "isRequired": function () {}
    },
    "isDraggable": {
      "isRequired": function () {}
    },
    "isResizable": {
      "isRequired": function () {}
    },
    "layout": function () {},
    "margin": {
      "isRequired": function () {}
    },
    "maxRows": {
      "isRequired": function () {}
    },
    "onDrag": {
      "isRequired": function () {}
    },
    "onDragStart": {
      "isRequired": function () {}
    },
    "onDragStop": {
      "isRequired": function () {}
    },
    "onLayoutChange": {
      "isRequired": function () {}
    },
    "onResize": {
      "isRequired": function () {}
    },
    "onResizeStart": {
      "isRequired": function () {}
    },
    "onResizeStop": {
      "isRequired": function () {}
    },
    "rowHeight": {
      "isRequired": function () {}
    },
    "style": {
      "isRequired": function () {}
    },
    "useCSSTransforms": {
      "isRequired": function () {}
    },
    "verticalCompact": {
      "isRequired": function () {}
    },
    "width": {
      "isRequired": function () {}
    }
  },
  "utils": {
    "__esModule": {},
    "autoBindHandlers": function () {},
    "bottom": function () {},
    "childrenEqual": function () {},
    "cloneLayout": function () {},
    "cloneLayoutItem": function () {},
    "collides": function () {},
    "compact": function () {},
    "compactItem": function () {},
    "correctBounds": function () {},
    "getAllCollisions": function () {},
    "getFirstCollision": function () {},
    "getLayoutItem": function () {},
    "getStatics": function () {},
    "moveElement": function () {},
    "moveElementAwayFromCollision": function () {},
    "perc": function () {},
    "setTopLeft": function () {},
    "setTransform": function () {},
    "sortLayoutItemsByRowCol": function () {},
    "synchronizeLayoutWithChildren": function () {},
    "validateLayout": function () {}
  }
};
ReactGridLayout.prototype = {
  "componentDidMount": function () {},
  "componentWillReceiveProps": function () {},
  "containerHeight": function () {},
  "forceUpdate": function () {},
  "isReactComponent": function () {},
  "onDrag": function () {},
  "onDragStart": function () {},
  "onDragStop": function () {},
  "onLayoutMaybeChanged": function () {},
  "onResize": function () {},
  "onResizeStart": function () {},
  "onResizeStop": function () {},
  "placeholder": function () {},
  "processGridItem": function () {},
  "render": function () {},
  "setState": function () {}
};
ReactGridLayout.Responsive.prototype = {
  "componentWillReceiveProps": function () {},
  "forceUpdate": function () {},
  "generateInitialState": function () {},
  "isReactComponent": function () {},
  "onWidthChange": function () {},
  "render": function () {},
  "setState": function () {}
};
/**********************************************************************
 * End Generated Extern for ReactGridLayout
/**********************************************************************/
